import { jsx, jsxs, Fragment } from "react/jsx-runtime";
import { useCallback } from "react";
import { LinkProvider } from "@netlify/ui";
import { SvgProvider, defaultImportSvg } from "./components/SvgProvider.js";
import { NetlifySDKProvider } from "./NetlifySDKProvider.js";
import { useNetlifySDK } from "./use_netlify_sdk.js";
import { useWindowResizer } from "./use_window_resizer.js";
import { Theme } from "./theme/Theme.js";
const Resizer = ({ children }) => {
  useWindowResizer();
  return /* @__PURE__ */ jsx(Fragment, { children });
};
const renderLink = ({ to, href, ...otherProps }) => {
  const sdk = useNetlifySDK();
  const onNavigation = useCallback(
    (event) => {
      event.preventDefault();
      if (to !== void 0) {
        sdk.routing.to(to);
      }
    },
    [to, sdk.routing]
  );
  if (to !== void 0 && to !== "") {
    return /* @__PURE__ */ jsx("a", { ...otherProps, onClick: onNavigation });
  }
  return /* @__PURE__ */ jsx("a", { ...otherProps, href, rel: "noopener noreferrer", target: "_blank" });
};
const NetlifyUIExtension = ({ children }) => {
  return /* @__PURE__ */ jsx(NetlifySDKProvider, { children: /* @__PURE__ */ jsx(Resizer, { children: /* @__PURE__ */ jsx(SvgProvider, { importSvg: defaultImportSvg, children: /* @__PURE__ */ jsxs(LinkProvider, { renderLink, children: [
    /* @__PURE__ */ jsx(Theme, {}),
    children
  ] }) }) }) });
};
export {
  NetlifyUIExtension
};
//# sourceMappingURL=NetlifyUIExtension.js.map
