import { default as React, ReactElement } from 'react';
import { DefaultValues } from 'react-hook-form';
import { ZodObject, z } from 'zod';

export declare const Form: <T extends ZodObject<any>>({ schema, defaultValues, children, onSubmit, onCancel, disabled, submitLabel, loading, }: {
    /**
     * Zod schema for form validation. Types for defaultValues and onSubmit callback parameters are derived from this schema.
     * Ensure compatibility by using the same Zod version as this package `sdk--ui-react`
     */
    schema?: T;
    /**
     * Initial form values, with types inferred from the provided zod `schema`
     */
    defaultValues?: DefaultValues<z.infer<T>>;
    /**
     * Callback function for handling form submissions. The types are automatically inferred from the provided zod `schema`
     */
    onSubmit?: ((data: z.infer<T>) => Promise<void> | void) | undefined;
    onCancel?: () => void;
    /**
     * Disables the form submit and resets to default values
     * @default false
     */
    disabled?: boolean;
    /**
     * Each child component provided with a `name` prop will automatically receive `register`, `control`, and `error` props from `react-hook-form`
     */
    children?: ReactElement | ReactElement[];
    /**
     * Label for the submit button
     * @default "Save"
     */
    submitLabel?: string | undefined;
    /**
     * Overrides the loading state of the form
     */
    loading?: boolean | undefined;
}) => React.JSX.Element;
//# sourceMappingURL=Form.d.ts.map